package org.foxarmy.barcodescannerforemployees.activities

import android.app.Activity
import android.content.SharedPreferences
import android.os.Bundle
import android.widget.Button
import android.widget.EditText
import android.widget.Toast
import androidx.security.crypto.EncryptedSharedPreferences
import androidx.security.crypto.MasterKeys
import org.foxarmy.barcodescannerforemployees.DBStorageController
import org.foxarmy.barcodescannerforemployees.R
import org.foxarmy.barcodescannerforemployees.dataclasses.Category

class AddCategoryActivity : Activity() {

    private lateinit var db: DBStorageController
    private lateinit var sharedPreferences: SharedPreferences

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        setContentView(R.layout.activity_add_category)

        sharedPreferences = EncryptedSharedPreferences.create(
            "sensitive",
            MasterKeys.getOrCreate(MasterKeys.AES256_GCM_SPEC),
            applicationContext,
            EncryptedSharedPreferences.PrefKeyEncryptionScheme.AES256_SIV,
            EncryptedSharedPreferences.PrefValueEncryptionScheme.AES256_GCM
        )

        db = DBStorageController(this, sharedPreferences.getString("currentGroup", "database")!!)

        val extras = intent.extras
        val category = extras!!.get("category") as Category?

        val categoryNameTextEdit: EditText = findViewById(R.id.newCategoryName)

        categoryNameTextEdit.setText(category!!.name)

        findViewById<Button>(R.id.saveButton).setOnClickListener {
            if (categoryNameTextEdit.text.toString() == "") {
                Toast.makeText(this, getString(R.string.category_name_required), Toast.LENGTH_SHORT).show()
                return@setOnClickListener
            }

            if (category.id == 0) { // Inserting new category
                db.addCategory(Category(0, categoryNameTextEdit.text.toString()))
            } else { // Updating existing category
                db.updateCategory(category)
            }

            finish()
        }
    }

    override fun onDestroy() {
        super.onDestroy()

        db.close()
    }
}